2022-06-09 Version: 2.5.2
- Add StartGameLive.
- Add StopGameLive.

2022-05-16 Version: 2.5.1
- Add GetGameStock.

2022-04-27 Version: 2.5.0
- Add SetGameAlive.

2021-12-22 Version: 2.0.1
- Netease.

2021-07-06 Version: 1.0.1
- Supported CPS Order.

2021-06-22 Version: 1.0.0
- Supported CPS Order.

